@@ -4,7 +4,7 @@
 
 __author__ = 'DiggerWorks'
 __email__ = 'support@digger.works'
-__version__ = '0.0.6'
+__version__ = '0.0.10'
 
 from Digo import DigoCore
 from Digo import Error
@@ -33,6 +33,8 @@ def imageLog(log):
     else:
         raise Error.InvalidType
 
+def upload_test(file):
+    core.upload_test(file)
 
 def uploadModel(model_path):
     core.uploadModel(model_path)
